
import { Button, Navigator, ScrollView, Text, View } from "@tarojs/components"
import { memo, useEffect, useState } from "react"
import "./index.scss"
import {addressListApi} from "@/api/addressManager"

interface Params{
  refresherEnabled?: boolean,//是否开启刷新
  onSelect?: (item:any,index:number)=>void,//列表选择

}

// 地址列表
const AddressList = memo((props:Params)=>{
  const {fetchData, state} = addressListApi()
  // 获取数据
  const getData = ()=>{
    fetchData();
  }
  useEffect(()=>{
    getData();
  },[])

  // 处理刷新
  const [refreshState, setRefreshState] = useState(false);
  const handleRefresh = async ()=>{
    setRefreshState(true);
    await fetchData();
    setRefreshState(false);
  }
  const data = Array.from({length:15});

  return (
    <View className="address-scroll-view">
      <ScrollView scrollY refresherEnabled={props.refresherEnabled} enhanced refresherTriggered={refreshState} onRefresherRefresh={handleRefresh}>
        {
          state?.data?.list?.length>0?
          state?.data?.list?.map((item,index)=>{
          // data.length>0?
          // data.map((item,index)=>{
            return(
              <View onClick={()=>props.onSelect&&props.onSelect(item,index)} className={`address-list ${item.is_default&&'address-active'}`}>
                <View className="address-user">
                  {item.name}
                  {
                    item.is_default?<Text className="address-list-default">默认</Text>:
                    <Text className="address-list-phone">{item.phone}</Text>
                  }
                </View>
                <View className="address-list-bottom">
                  <View className="address-list-info">
                    {/* **省**市**区**街道****仓库 */}
                    {item.province_name+item.city_name+item.district_name} {item.address_detail}
                    {
                      item.is_default&&<Text className="address-list-phone">{item.phone}</Text>
                    }
                  </View>
                  <Navigator url={`/pages/addressAdd/index?type=edit&id=${item.id}`} hoverClass="none" className="address-edit">
                    <Text className="iconfont icon-bianji"></Text>
                  </Navigator>
                </View>
              </View>
            );
          }):
          <View className="address-no-data">暂未添加地址</View>
        }
      </ScrollView>
      <Navigator url="/pages/addressAdd/index?type=add" hoverClass="none" className="add-address">添加收货地址</Navigator>
    </View>
  )
})

export default AddressList;